@@ -1,17 +1,17 @@
 use ansi_term::Colour::Red;
-use structopt::{
-    clap::{crate_version, AppSettings},
-    StructOpt,
-};
+use clap::{crate_version, AppSettings, Parser};
 
-use debcargo::build_order::{build_order, BuildOrderArgs};
-use debcargo::crates::{update_crates_io, CrateInfo};
+use debcargo::crates::CrateInfo;
 use debcargo::debian::DebInfo;
 use debcargo::errors::Result;
 use debcargo::package::*;
+use debcargo::{
+    build_order::{build_order, BuildOrderArgs},
+    crates::invalidate_crates_io_cache,
+};
 
-#[derive(Debug, Clone, StructOpt)]
-#[structopt(name = "debcargo", about = "Package Rust crates for Debian.")]
+#[derive(Debug, Clone, Parser)]
+#[clap(name = "debcargo", about = "Package Rust crates for Debian.")]
 enum Opt {
     /// Update the user's default crates.io index, outside of a workspace.
     Update,
@@ -27,34 +27,41 @@ enum Opt {
     },
     /// Extract only a crate, without any other transformations.
     Extract {
-        #[structopt(flatten)]
+        #[clap(flatten)]
         init: PackageInitArgs,
-        #[structopt(flatten)]
+        #[clap(flatten)]
         extract: PackageExtractArgs,
     },
     /// Package a Rust crate for Debian.
     Package {
-        #[structopt(flatten)]
+        #[clap(flatten)]
         init: PackageInitArgs,
-        #[structopt(flatten)]
+        #[clap(flatten)]
         extract: PackageExtractArgs,
-        #[structopt(flatten)]
+        #[clap(flatten)]
         finish: PackageExecuteArgs,
     },
     /// Print the transitive dependencies of a package in topological order.
     BuildOrder {
-        #[structopt(flatten)]
+        #[clap(flatten)]
         args: BuildOrderArgs,
     },
 }
 
+#[test]
+fn verify_app() {
+    use clap::IntoApp;
+    Opt::into_app().debug_assert()
+}
+
 fn real_main() -> Result<()> {
     let m = Opt::clap()
+        .version(crate_version!())
         .global_setting(AppSettings::ColoredHelp)
         .get_matches();
     use Opt::*;
     match Opt::from_clap(&m) {
-        Update => update_crates_io(),
+        Update => invalidate_crates_io_cache(),
         DebSrcName {
             crate_name,
             version,
