@@ -19,7 +19,7 @@ pub struct Source {
     vcs_git: String,
     vcs_browser: String,
     homepage: String,
-    x_cargo: String,
+    crate_name: String,
     requires_root: String,
 }
 
@@ -70,9 +70,13 @@ impl fmt::Display for Source {
             writeln!(f, "Homepage: {}", self.homepage)?;
         }
 
-        if !self.x_cargo.is_empty() {
-            writeln!(f, "X-Cargo-Crate: {}", self.x_cargo)?;
-        }
+        // We used to set this conditionally, however it's best to do it
+        // unconditionally as some crates' names have a number suffix e.g.
+        // "utf-8". Without setting X-Cargo-Crate, we cannot distinguish:
+        //   a) "utf" crate at version 8 with semver_suffix = true
+        //   b) "utf-8" crate at version latest with semver_suffix = false.
+        // dh-cargo assumes (a) which is wrong for the "utf-8" crate
+        writeln!(f, "X-Cargo-Crate: {}", self.crate_name)?;
         writeln!(f, "Rules-Requires-Root: {}", self.requires_root)?;
 
         Ok(())
@@ -111,12 +115,15 @@ impl fmt::Display for Package {
 
 impl fmt::Display for PkgTest {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        let extra_args = if self.extra_test_args.is_empty() {
+            "".into()
+        } else {
+            format!(" {}", self.extra_test_args.join(" "))
+        };
         writeln!(
             f,
-            "Test-Command: /usr/share/cargo/bin/cargo-auto-test {} {} --all-targets {}",
-            self.crate_name,
-            self.version,
-            self.extra_test_args.join(" ")
+            "Test-Command: /usr/share/cargo/bin/cargo-auto-test {} {} --all-targets{}",
+            self.crate_name, self.version, extra_args,
         )?;
         writeln!(f, "Features: test-name={}:{}", &self.name, &self.feature)?;
         // TODO: drop the below workaround when rust-lang/cargo#5133 is fixed.
@@ -124,25 +131,24 @@ impl fmt::Display for PkgTest {
         // must be installed, which makes it harder to actually run the tests
         let cargo_bug_fixed = false;
         let default_deps = if cargo_bug_fixed { &self.name } else { "@" };
-        if self.depends.is_empty() {
-            writeln!(f, "Depends: dh-cargo (>= 18), {}", default_deps)?;
+
+        let depends = if self.depends.is_empty() {
+            "".into()
         } else {
-            writeln!(
-                f,
-                "Depends: dh-cargo (>= 18), {}, {}",
-                self.depends.join(", "),
-                default_deps
-            )?;
-        }
-        if self.extra_restricts.is_empty() {
-            writeln!(f, "Restrictions: allow-stderr, skip-not-installable")?;
+            format!(", {}", self.depends.join(", "))
+        };
+        writeln!(f, "Depends: dh-cargo (>= 18){}, {}", depends, default_deps)?;
+
+        let restricts = if self.extra_restricts.is_empty() {
+            "".into()
         } else {
-            writeln!(
-                f,
-                "Restrictions: allow-stderr, skip-not-installable, {}",
-                self.extra_restricts.join(", ")
-            )?;
-        }
+            format!(", {}", self.extra_restricts.join(", "))
+        };
+        writeln!(
+            f,
+            "Restrictions: allow-stderr, skip-not-installable{}",
+            restricts,
+        )?;
         Ok(())
     }
 }
@@ -161,7 +167,7 @@ impl Source {
     pub fn new(
         basename: &str,
         name_suffix: Option<&str>,
-        upstream_name: &str,
+        crate_name: &str,
         home: &str,
         lib: bool,
         maintainer: String,
@@ -187,24 +193,18 @@ impl Source {
             "https://salsa.debian.org/rust-team/debcargo-conf.git [src/{}]",
             pkgbase
         );
-
-        let cargo_crate = if upstream_name != base_deb_name(upstream_name) {
-            upstream_name.to_string()
-        } else {
-            "".to_string()
-        };
         Ok(Source {
             name: dsc_name(&pkgbase),
             section: section.to_string(),
             priority,
             maintainer,
             uploaders,
-            standards: "4.5.1".to_string(),
+            standards: "4.6.1".to_string(),
             build_deps,
             vcs_git,
             vcs_browser,
             homepage: home.to_string(),
-            x_cargo: cargo_crate,
+            crate_name: crate_name.to_string(),
             requires_root: "no".to_string(),
         })
     }
@@ -585,3 +585,6 @@ pub fn get_deb_author() -> Result<String> {
     })?;
     Ok(format!("{} <{}>", name, email))
 }
+
+#[cfg(test)]
+mod tests;
